Source code & Development:
    https://mangenerator.sourceforge.io
Doxygen documentation:
    http://turulomio.users.sourceforge.net/doxygen/mangenerator/
Main developer web page:
    http://turulomio.users.sourceforge.net/en/proyectos.html
Gentoo ebuild
    You can find a Gentoo ebuild in https://sourceforge.net/p/mangenerator/code/HEAD/tree/myportage/dev-python/mangenerator/

Description
===========
Module to generate man pages quickly

License
=======
GPL-3

Dependencies
============
None, other than Python. Tested on Python 3 

Usage
=====
You can see main function in mangenerator.mangenerator file

Changelog
=========
0.4.0
  * Now you can change html output
0.3.0
  * Catalog is now inside the package
0.2.0
  * Basic funcionality

